@@ -5,133 +5,115 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="302"/>
-        <location filename="../ui_mainwindow.h" line="225"/>
+        <location filename="../mainwindow.cpp" line="371"/>
         <source>MX Service Manager</source>
         <translation>MX Gestor de servicios</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="26"/>
-        <location filename="../mainwindow.cpp" line="157"/>
-        <location filename="../mainwindow.cpp" line="317"/>
-        <location filename="../ui_mainwindow.h" line="226"/>
+        <location filename="../mainwindow.cpp" line="153"/>
+        <location filename="../mainwindow.cpp" line="386"/>
         <source>&amp;Enable at boot</source>
         <translation>&amp;Activar en el arranque</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="62"/>
-        <location filename="../ui_mainwindow.h" line="228"/>
         <source>About this application</source>
         <translation>Acerca de esta aplicación</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="65"/>
-        <location filename="../ui_mainwindow.h" line="230"/>
         <source>&amp;About...</source>
         <translation>&amp;Acerca de...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="72"/>
-        <location filename="../ui_mainwindow.h" line="232"/>
+        <location filename="../mainwindow.ui" line="71"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="126"/>
-        <location filename="../ui_mainwindow.h" line="236"/>
+        <location filename="../mainwindow.ui" line="125"/>
         <source>Display help </source>
         <translation>Mostrar la ayuda </translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="129"/>
-        <location filename="../ui_mainwindow.h" line="238"/>
+        <location filename="../mainwindow.ui" line="128"/>
         <source>&amp;Help</source>
         <translation>A&amp;yuda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="136"/>
-        <location filename="../ui_mainwindow.h" line="240"/>
+        <location filename="../mainwindow.ui" line="134"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="168"/>
-        <location filename="../ui_mainwindow.h" line="243"/>
+        <location filename="../mainwindow.ui" line="166"/>
         <source>Quit application</source>
         <translation>Salir de la aplicación</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="171"/>
-        <location filename="../ui_mainwindow.h" line="245"/>
+        <location filename="../mainwindow.ui" line="169"/>
         <source>&amp;Close</source>
         <translation>&amp;Cerrar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="178"/>
-        <location filename="../ui_mainwindow.h" line="247"/>
+        <location filename="../mainwindow.ui" line="175"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="203"/>
-        <location filename="../mainwindow.cpp" line="139"/>
-        <location filename="../ui_mainwindow.h" line="250"/>
+        <location filename="../mainwindow.ui" line="216"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>&amp;Stop</source>
         <translation>&amp;Detener</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="217"/>
-        <location filename="../ui_mainwindow.h" line="251"/>
+        <location filename="../mainwindow.ui" line="230"/>
+        <location filename="../mainwindow.cpp" line="315"/>
         <source>All services</source>
         <translation>Todos los servicios</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="222"/>
-        <location filename="../mainwindow.cpp" line="277"/>
-        <location filename="../ui_mainwindow.h" line="252"/>
+        <location filename="../mainwindow.ui" line="235"/>
+        <location filename="../mainwindow.cpp" line="316"/>
         <source>Running services</source>
         <translation>Servicios de ejecución</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="227"/>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <location filename="../ui_mainwindow.h" line="253"/>
+        <location filename="../mainwindow.ui" line="240"/>
+        <location filename="../mainwindow.cpp" line="317"/>
         <source>Services enabled at boot</source>
         <translation>Servicios activados en el arranque</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="232"/>
-        <location filename="../mainwindow.cpp" line="279"/>
-        <location filename="../ui_mainwindow.h" line="254"/>
+        <location filename="../mainwindow.ui" line="245"/>
+        <location filename="../mainwindow.cpp" line="318"/>
         <source>Services disabled at boot</source>
         <translation>Servicios desactivados en el arranque</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="268"/>
-        <location filename="../ui_mainwindow.h" line="257"/>
+        <location filename="../mainwindow.ui" line="281"/>
         <source>search</source>
         <translation>Buscar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="278"/>
+        <location filename="../mainwindow.ui" line="291"/>
         <location filename="../mainwindow.cpp" line="68"/>
         <location filename="../mainwindow.cpp" line="81"/>
-        <location filename="../ui_mainwindow.h" line="258"/>
         <source>Loading...</source>
         <translation>Cargando...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="297"/>
-        <location filename="../ui_mainwindow.h" line="259"/>
+        <location filename="../mainwindow.ui" line="310"/>
         <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
         <translation>Esta herramienta enumera los servicios y demonios (procesos que se ejecutan en segundo plano) que se encuentran en este sistema. Tenga cuidado de no detener algo que pueda interrumpir un componente crítico; es mejor no hacerlo si no sabe lo que es.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="62"/>
-        <location filename="../mainwindow.cpp" line="319"/>
-        <location filename="../mainwindow.cpp" line="326"/>
-        <location filename="../mainwindow.cpp" line="347"/>
-        <location filename="../mainwindow.cpp" line="356"/>
+        <location filename="../mainwindow.cpp" line="388"/>
+        <location filename="../mainwindow.cpp" line="395"/>
+        <location filename="../mainwindow.cpp" line="416"/>
+        <location filename="../mainwindow.cpp" line="425"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
@@ -141,101 +123,101 @@
         <translation>No se ha podido determinar el sistema init. Se supone que este programa se ejecuta con systemd o sysvinit.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="144"/>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="414"/>
         <source>S&amp;tart</source>
         <translation>&amp;Inicio</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="146"/>
         <source>&amp;Disable at boot</source>
         <translation>&amp;Desactivar en el arranque</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
+        <location filename="../mainwindow.cpp" line="351"/>
         <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 total de servicios, %2 actualmente &lt;font color=&apos;%3&apos;&gt;en ejecución&lt;/font&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="../mainwindow.cpp" line="356"/>
         <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 &lt;font color=&apos;%2&apos;&gt;activados&lt;/font&gt; en el arranque, pero no en ejecución</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="302"/>
+        <location filename="../mainwindow.cpp" line="371"/>
         <source>About %1</source>
         <translation>Acerca de %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="303"/>
+        <location filename="../mainwindow.cpp" line="372"/>
         <source>Version: </source>
         <translation>Versión: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="304"/>
+        <location filename="../mainwindow.cpp" line="373"/>
         <source>Service and daemon manager</source>
         <translation>Gestor de servicios y demonios</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="306"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Derechos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="307"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>%1 License</source>
         <translation>%1 Licencia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="319"/>
+        <location filename="../mainwindow.cpp" line="388"/>
         <source>Could not enable %1</source>
         <translation>No se pudo activar %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="323"/>
-        <location filename="../mainwindow.cpp" line="330"/>
-        <location filename="../mainwindow.cpp" line="352"/>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../mainwindow.cpp" line="392"/>
+        <location filename="../mainwindow.cpp" line="399"/>
+        <location filename="../mainwindow.cpp" line="421"/>
+        <location filename="../mainwindow.cpp" line="430"/>
         <source>Success</source>
         <translation>Exito</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="323"/>
+        <location filename="../mainwindow.cpp" line="392"/>
         <source>%1 was enabled at boot time.</source>
         <translation>%1 fue activado en el arranque.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="326"/>
+        <location filename="../mainwindow.cpp" line="395"/>
         <source>Could not disable %1</source>
         <translation>No se pudo desactivar %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="330"/>
+        <location filename="../mainwindow.cpp" line="399"/>
         <source>%1 was disabled.</source>
         <translation>%1 fue desactivado.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="337"/>
+        <location filename="../mainwindow.cpp" line="406"/>
         <source>%1 Help</source>
         <translation>%1 Ayuda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../mainwindow.cpp" line="416"/>
         <source>Could not start %1</source>
         <translation>No se pudo iniciar %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="352"/>
+        <location filename="../mainwindow.cpp" line="421"/>
         <source>%1 was started.</source>
         <translation>%1 fue iniciado.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="356"/>
+        <location filename="../mainwindow.cpp" line="425"/>
         <source>Could not stop %1</source>
         <translation>No se pudo detener %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../mainwindow.cpp" line="430"/>
         <source>%1 was stopped.</source>
         <translation>%1 fue detenido.</translation>
     </message>
@@ -280,7 +262,7 @@
         <translation>Debe ejecutar este programa con acceso de administrador.</translation>
     </message>
     <message>
-        <location filename="../service.cpp" line="116"/>
+        <location filename="../service.cpp" line="124"/>
         <source>Could not find service description</source>
         <translation>No se encontró la descripción del servicio</translation>
     </message>
