@@ -5,133 +5,115 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="302"/>
-        <location filename="../ui_mainwindow.h" line="225"/>
+        <location filename="../mainwindow.cpp" line="371"/>
         <source>MX Service Manager</source>
         <translation>MX Tjänste-hanterare</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="26"/>
-        <location filename="../mainwindow.cpp" line="157"/>
-        <location filename="../mainwindow.cpp" line="317"/>
-        <location filename="../ui_mainwindow.h" line="226"/>
+        <location filename="../mainwindow.cpp" line="153"/>
+        <location filename="../mainwindow.cpp" line="386"/>
         <source>&amp;Enable at boot</source>
         <translation>&amp;Aktivera vid boot</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="62"/>
-        <location filename="../ui_mainwindow.h" line="228"/>
         <source>About this application</source>
         <translation>Om detta program</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="65"/>
-        <location filename="../ui_mainwindow.h" line="230"/>
         <source>&amp;About...</source>
         <translation>&amp;Om...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="72"/>
-        <location filename="../ui_mainwindow.h" line="232"/>
+        <location filename="../mainwindow.ui" line="71"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="126"/>
-        <location filename="../ui_mainwindow.h" line="236"/>
+        <location filename="../mainwindow.ui" line="125"/>
         <source>Display help </source>
         <translation>Visa hjälp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="129"/>
-        <location filename="../ui_mainwindow.h" line="238"/>
+        <location filename="../mainwindow.ui" line="128"/>
         <source>&amp;Help</source>
         <translation>&amp;Hjälp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="136"/>
-        <location filename="../ui_mainwindow.h" line="240"/>
+        <location filename="../mainwindow.ui" line="134"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="168"/>
-        <location filename="../ui_mainwindow.h" line="243"/>
+        <location filename="../mainwindow.ui" line="166"/>
         <source>Quit application</source>
         <translation>Avsluta programmet</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="171"/>
-        <location filename="../ui_mainwindow.h" line="245"/>
+        <location filename="../mainwindow.ui" line="169"/>
         <source>&amp;Close</source>
         <translation>&amp;Stäng</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="178"/>
-        <location filename="../ui_mainwindow.h" line="247"/>
+        <location filename="../mainwindow.ui" line="175"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="203"/>
-        <location filename="../mainwindow.cpp" line="139"/>
-        <location filename="../ui_mainwindow.h" line="250"/>
+        <location filename="../mainwindow.ui" line="216"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>&amp;Stop</source>
         <translation>&amp;Stopp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="217"/>
-        <location filename="../ui_mainwindow.h" line="251"/>
+        <location filename="../mainwindow.ui" line="230"/>
+        <location filename="../mainwindow.cpp" line="315"/>
         <source>All services</source>
         <translation>Alla tjänster</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="222"/>
-        <location filename="../mainwindow.cpp" line="277"/>
-        <location filename="../ui_mainwindow.h" line="252"/>
+        <location filename="../mainwindow.ui" line="235"/>
+        <location filename="../mainwindow.cpp" line="316"/>
         <source>Running services</source>
         <translation>Tjänster som körs</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="227"/>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <location filename="../ui_mainwindow.h" line="253"/>
+        <location filename="../mainwindow.ui" line="240"/>
+        <location filename="../mainwindow.cpp" line="317"/>
         <source>Services enabled at boot</source>
         <translation>Tjänster aktiverade vid boot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="232"/>
-        <location filename="../mainwindow.cpp" line="279"/>
-        <location filename="../ui_mainwindow.h" line="254"/>
+        <location filename="../mainwindow.ui" line="245"/>
+        <location filename="../mainwindow.cpp" line="318"/>
         <source>Services disabled at boot</source>
         <translation>Tjänster avaktiverade vid boot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="268"/>
-        <location filename="../ui_mainwindow.h" line="257"/>
+        <location filename="../mainwindow.ui" line="281"/>
         <source>search</source>
         <translation>sök</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="278"/>
+        <location filename="../mainwindow.ui" line="291"/>
         <location filename="../mainwindow.cpp" line="68"/>
         <location filename="../mainwindow.cpp" line="81"/>
-        <location filename="../ui_mainwindow.h" line="258"/>
         <source>Loading...</source>
         <translation>Laddar...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="297"/>
-        <location filename="../ui_mainwindow.h" line="259"/>
+        <location filename="../mainwindow.ui" line="310"/>
         <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
         <translation>Detta verktyg listar tjänster och daemons (processer som körs i bakgrunden) funna i detta system. Var noggrann med att undvika att stoppa något som kanstöra en kritisk komponent; bäst att lämna det i fred om du inte vet vad det är.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="62"/>
-        <location filename="../mainwindow.cpp" line="319"/>
-        <location filename="../mainwindow.cpp" line="326"/>
-        <location filename="../mainwindow.cpp" line="347"/>
-        <location filename="../mainwindow.cpp" line="356"/>
+        <location filename="../mainwindow.cpp" line="388"/>
+        <location filename="../mainwindow.cpp" line="395"/>
+        <location filename="../mainwindow.cpp" line="416"/>
+        <location filename="../mainwindow.cpp" line="425"/>
         <source>Error</source>
         <translation>Fel</translation>
     </message>
@@ -141,101 +123,101 @@
         <translation>Kunde inte bestämma init system. Detta program antas kunna köras endera med systemd eller sysvinit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="144"/>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="414"/>
         <source>S&amp;tart</source>
         <translation>S&amp;tart</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="146"/>
         <source>&amp;Disable at boot</source>
         <translation>&amp;Deaktivera vid boot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
+        <location filename="../mainwindow.cpp" line="351"/>
         <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 totala tjänster, %2 för närvarande &lt;font color=&apos;%3&apos;&gt;körda&lt;/font&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="../mainwindow.cpp" line="356"/>
         <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 &lt;font color=&apos;%2&apos;&gt;aktiverade&lt;/font&gt; från start, men körs ej</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="302"/>
+        <location filename="../mainwindow.cpp" line="371"/>
         <source>About %1</source>
         <translation>Om %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="303"/>
+        <location filename="../mainwindow.cpp" line="372"/>
         <source>Version: </source>
         <translation>Version:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="304"/>
+        <location filename="../mainwindow.cpp" line="373"/>
         <source>Service and daemon manager</source>
         <translation>Tjänste och daemon hanterare</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="306"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="307"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>%1 License</source>
         <translation>%1 Licens</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="319"/>
+        <location filename="../mainwindow.cpp" line="388"/>
         <source>Could not enable %1</source>
         <translation>Kunde inte aktivera %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="323"/>
-        <location filename="../mainwindow.cpp" line="330"/>
-        <location filename="../mainwindow.cpp" line="352"/>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../mainwindow.cpp" line="392"/>
+        <location filename="../mainwindow.cpp" line="399"/>
+        <location filename="../mainwindow.cpp" line="421"/>
+        <location filename="../mainwindow.cpp" line="430"/>
         <source>Success</source>
         <translation>Det lyckades</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="323"/>
+        <location filename="../mainwindow.cpp" line="392"/>
         <source>%1 was enabled at boot time.</source>
         <translation>%1 var aktiverade vid boot.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="326"/>
+        <location filename="../mainwindow.cpp" line="395"/>
         <source>Could not disable %1</source>
         <translation>Kunde inte avaktivera %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="330"/>
+        <location filename="../mainwindow.cpp" line="399"/>
         <source>%1 was disabled.</source>
         <translation>%1 var avaktiverad.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="337"/>
+        <location filename="../mainwindow.cpp" line="406"/>
         <source>%1 Help</source>
         <translation>%1 Hjälp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../mainwindow.cpp" line="416"/>
         <source>Could not start %1</source>
         <translation>Kunde inte starta %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="352"/>
+        <location filename="../mainwindow.cpp" line="421"/>
         <source>%1 was started.</source>
         <translation>%1 startades.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="356"/>
+        <location filename="../mainwindow.cpp" line="425"/>
         <source>Could not stop %1</source>
         <translation>Kunde inte stoppa %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../mainwindow.cpp" line="430"/>
         <source>%1 was stopped.</source>
         <translation>%1 stoppades.</translation>
     </message>
@@ -280,7 +262,7 @@
         <translation>Du måste köra detta program med administratörsrättigheter.</translation>
     </message>
     <message>
-        <location filename="../service.cpp" line="116"/>
+        <location filename="../service.cpp" line="124"/>
         <source>Could not find service description</source>
         <translation>Kunde inte hitta tjänstbeskrivning</translation>
     </message>
